==> haskell-crypton-connection-0.4.5-18-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-connection.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-connection
version:              0.4.5
visibility:           public
id:                   crypton-connection-0.4.5-2c10WiKFU3L73agHYaksHE
key:                  crypton-connection-0.4.5-2c10WiKFU3L73agHYaksHE
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-connection
synopsis:             Simple and easy network connection API
description:
    Simple network library for all your connection needs.

    Features: Really simple to use, SSL/TLS, SOCKS.

    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.

category:             Network
abi:                  906a22c89f698fbbd24d0d3c6f192f06
exposed:              True
exposed-modules:      Network.Connection Network.Connection.Internal
hidden-modules:       Network.Connection.Types
import-dirs:          /usr/lib/ghc-9.6.6/site-local/crypton-connection-0.4.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/crypton-connection-0.4.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/crypton-connection-0.4.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-connection
hs-libraries:         HScrypton-connection-0.4.5-2c10WiKFU3L73agHYaksHE
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    crypton-socks-0.6.2-FXreg67xl21Hj9z7aDM5dc
    crypton-x509-store-1.6.12-8u0cMDz1Er0H0crmNaS9QT
    crypton-x509-system-1.6.7-AlhozJnZLRBLBROfMMJw3u
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe
    tls-2.0.6-HHKVvNcSfLyJGme2UrIiax

haddock-interfaces:
    /usr/share/doc/haskell-crypton-connection/html/crypton-connection.haddock

haddock-html:         /usr/share/doc/haskell-crypton-connection/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-connection-0.4.5-19-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-connection.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-connection
version:              0.4.5
visibility:           public
id:                   crypton-connection-0.4.5-EMMKhGKvDZ19xloyuzywis
key:                  crypton-connection-0.4.5-EMMKhGKvDZ19xloyuzywis
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-connection
synopsis:             Simple and easy network connection API
description:
    Simple network library for all your connection needs.

    Features: Really simple to use, SSL/TLS, SOCKS.

    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.

category:             Network
abi:                  b9dee03590bdce883fe31f555503e543
exposed:              True
exposed-modules:      Network.Connection Network.Connection.Internal
hidden-modules:       Network.Connection.Types
import-dirs:          /usr/lib/ghc-9.6.6/site-local/crypton-connection-0.4.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/crypton-connection-0.4.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/crypton-connection-0.4.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-connection
hs-libraries:         HScrypton-connection-0.4.5-EMMKhGKvDZ19xloyuzywis
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    crypton-socks-0.6.2-EQsvOrwsORa7DZhr3ArI9d
    crypton-x509-store-1.6.12-Kpp5jEsJnJk1mLM8EMOCOC
    crypton-x509-system-1.6.7-DQHBNlA1dz6FrhIVkM7QX0
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ
    tls-2.0.6-CMnie4Wyps5DmePV9nSMbU

haddock-interfaces:
    /usr/share/doc/haskell-crypton-connection/html/crypton-connection.haddock

haddock-html:         /usr/share/doc/haskell-crypton-connection/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
